@@ -3,6 +3,6 @@
 
 fn main() {
     let source = include_str!("./source/electrical-engineering.txt");
-    let html = subscript_compiler::compiler::compile_to_html(source);
+    let html = subscript_compiler::frontend::pass::to_html::compile_to_html(source);
     println!("{}", html);
 }
