@@ -30,7 +30,7 @@ pub fn run_cli() {
             if let Some(parent) = output_path.parent() {
                 let _ = std::fs::create_dir_all(parent);
             }
-            let output = crate::compiler::compile_to_html(&source);
+            let output = crate::frontend::pass::to_html::compile_to_html(&source);
             std::fs::write(&output_path, output).unwrap();
         }
     }
