@@ -1,6 +1,6 @@
 use std::borrow::Cow;
 use std::collections::HashMap;
-use crate::compiler::data::{LayoutKind, Text};
+use crate::frontend::data::{LayoutKind, Text};
 
 ///////////////////////////////////////////////////////////////////////////////
 // BASICS
@@ -124,15 +124,6 @@ impl<'a> Node<'a> {
     }
 }
 
-/// Convert **only** the given IR tree to HTML.
-pub fn render_ast_only<'a>(html: Vec<Node<'a>>) -> String {
-    html
-        .into_iter()
-        .map(Node::to_html_str)
-        .map(|x| x.0)
-        .collect::<Vec<_>>()
-        .join("\n")
-}
 
 /// Render the entire document.
 pub fn render_document<'a>(html: Vec<Node<'a>>) -> String {
@@ -142,44 +133,10 @@ pub fn render_document<'a>(html: Vec<Node<'a>>) -> String {
         .map(|x| x.0)
         .collect::<Vec<_>>()
         .join("\n");
-    let html = String::from(include_str!("../../assets/template.html.txt"));
-    let html = html.replace("{{deps}}", include_str!("../../assets/deps.html"));
-    let html = html.replace("{{css}}", include_str!("../../assets/styling.css"));
-    html.replace("{{body}}", &body)
-}
-
-/// Runtime dependencies; including local (embedded) css styling.
-pub fn runtime_dependencies() -> String {
-    let mut html = String::from(include_str!("../../assets/deps.html"));
-    let css = format!(
-        "<style>{}</style>",
-        include_str!("../../assets/styling.css")
-    );
-    html.push_str(&css);
-    html
-}
-
-///////////////////////////////////////////////////////////////////////////////
-// DEV
-///////////////////////////////////////////////////////////////////////////////
-
-pub(crate) fn dev() {
-    // let source = include_str!("../../source.txt");
-    // let parsed = crate::backend::parser::run_parser(source);
-    // let result = crate::backend::passes::to_html_pipeline(parsed);
-    // // let result = crate::frontend::parser::run_parser(source);
-    // // let result = passes(result);
-    // // let result = result
-    // //     .into_iter()
-    // //     .map(to_html)
-    // //     .collect::<Vec<_>>();
-    // for node in result.clone() {
-    //     println!("{:#?}", node.to_html_str());
-    // }
-    // // println!("------------------------------------------------------------");
-    // let output = render_document(result);
-    // // println!("{}", result);
-    // std::fs::write("output.html", output);
+    let html = String::from(include_str!("../../assets/template.html"));
+    let html = html.replace("<!--{{deps}}-->", include_str!("../../assets/deps.html"));
+    let html = html.replace("/*{{css}}*/", include_str!("../../assets/styling.css"));
+    html.replace("<!--{{body}}-->", &body)
 }
 
 
